==> haskell-simple-reflect-0.3.3-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-reflect.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 simple-reflect
version:              0.3.3
visibility:           public
id:                   simple-reflect-0.3.3-6bzc2HjUkxQ8Qu7G3Z5hdc
key:                  simple-reflect-0.3.3-6bzc2HjUkxQ8Qu7G3Z5hdc
license:              BSD-3-Clause
maintainer:           twanvl@gmail.com
author:               Twan van Laarhoven
homepage:
    http://twanvl.nl/blog/haskell/simple-reflection-of-expressions

synopsis:             Simple reflection of expressions containing variables
description:
    This package allows simple reflection of expressions containing variables.
    Reflection here means that a Haskell expression is turned into a string.
    The primary aim of this package is teaching and understanding;
    there are no options for manipulating the reflected expressions beyond showing them.

category:             Debug
abi:                  8704336cec91c0ca9589d19db9348026
exposed:              True
exposed-modules:
    Debug.SimpleReflect Debug.SimpleReflect.Expr
    Debug.SimpleReflect.Vars

import-dirs:          /usr/lib/ghc-9.2.8/site-local/simple-reflect-0.3.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/simple-reflect-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-simple-reflect
hs-libraries:         HSsimple-reflect-0.3.3-6bzc2HjUkxQ8Qu7G3Z5hdc
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-simple-reflect/html/simple-reflect.haddock

haddock-html:         /usr/share/doc/haskell-simple-reflect/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-simple-reflect-0.3.3-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-reflect.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 simple-reflect
version:              0.3.3
visibility:           public
id:                   simple-reflect-0.3.3-Kct69QODYQA4F7issyqpIH
key:                  simple-reflect-0.3.3-Kct69QODYQA4F7issyqpIH
license:              BSD-3-Clause
maintainer:           twanvl@gmail.com
author:               Twan van Laarhoven
homepage:
    http://twanvl.nl/blog/haskell/simple-reflection-of-expressions

synopsis:             Simple reflection of expressions containing variables
description:
    This package allows simple reflection of expressions containing variables.
    Reflection here means that a Haskell expression is turned into a string.
    The primary aim of this package is teaching and understanding;
    there are no options for manipulating the reflected expressions beyond showing them.

category:             Debug
abi:                  410ebfa5ced549086fa24efce70d94a6
exposed:              True
exposed-modules:
    Debug.SimpleReflect Debug.SimpleReflect.Expr
    Debug.SimpleReflect.Vars

import-dirs:          /usr/lib/ghc-9.4.8/site-local/simple-reflect-0.3.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/simple-reflect-0.3.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/simple-reflect-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-simple-reflect
hs-libraries:         HSsimple-reflect-0.3.3-Kct69QODYQA4F7issyqpIH
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-simple-reflect/html/simple-reflect.haddock

haddock-html:         /usr/share/doc/haskell-simple-reflect/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
